This function is mostly for the package's internal use, but we export it so you can try it out. However, we expect that you'll likely write your own function to simplify the result however you want.
Usage
show_works(x, simp_func = utils::head)Value
Simplified tibble to display. The first column, `id` is the short-form OpenAlex ID of the works. If `x` is `NULL` (which is what [oa_fetch()] returns when a query matched no records or the API request failed) or has zero rows, a zero-row tibble with these columns is returned, with a warning in the `NULL` case.